Module cell_context

Module cell_context 

Context provided when rendering a table cell.

Contains all information needed to render a cell value, including the row data, column information, and table state. Context provided when rendering a table cell.

Contains all information needed to render a cell value, including the row data, column information, and table state.

Structs

DataTableCellContext
Context provided when rendering a cell.