Module column_id

Module column_id 

Unique identifier for a table column.

Column IDs are used to reference columns throughout the table API for operations like sorting, filtering, visibility, and pinning. Unique identifier for a table column.

Column IDs are used to reference columns throughout the table API for operations like sorting, filtering, visibility, and pinning.

Structs

ColumnId
Unique identifier for a column.