Module column_meta

Module column_meta 

Metadata for a table column that affects its behavior and display.

Contains configuration such as header text, footer text, sortable/filterable flags, resize constraints, and group column settings. Metadata for a table column that affects its behavior and display.

Contains configuration such as header text, footer text, sortable/filterable flags, resize constraints, and group column settings.

Structs

ColumnMeta
Metadata for a column that affects its behavior.