Context provided when rendering a column header.
Contains sort state, filter capability, resize state, pinning status, and column width information. Context provided when rendering a column header.
Contains all information needed to render a column header, including sort state, filter capability, and resize state.
Structs
- Data
Table Header Context - Context provided when rendering a column header.