Custom aggregation function wrapper.
Allows users to provide custom aggregation functions for columns requiring specialized aggregation behavior in grouped rows. Custom aggregation function type for column-specific aggregation logic.
Allows users to provide custom aggregation functions for columns that require specialized aggregation behavior in grouped rows.
Structs
- Aggregation
Fn - Custom aggregation function type.