Module aggregation_state

Module aggregation_state 

Complete aggregation state for the table.

Manages column-level aggregation function assignments and provides configuration for aggregation behavior. Complete aggregation state for the table.

Manages column-level aggregation function assignments and provides configuration for aggregation behavior.

Structs

AggregationState
Complete aggregation state for the table.