Combined state for all table features.
Aggregates all feature states into a single structure for easier management and passing around. Combined state for all table features.
Aggregates all feature states into a single structure for easier management and passing around.
Structs
- Data
Table State - Combined state for all table features.