Module data_table

Module data_table 

Main table instance that coordinates all table functionality.

Manages columns, data, and state, providing methods for sorting, filtering, pagination, selection, and all other table operations. Main table instance that coordinates all table functionality.

DataTable is the primary entry point for interacting with the data table. It manages columns, data, and state, and provides methods for all table operations.

Structs

DataTable
Main table instance that coordinates all table functionality.