Metadata for a table column that affects its behavior and display.
Contains configuration such as header text, footer text, sortable/filterable flags, resize constraints, and group column settings. Metadata for a table column that affects its behavior and display.
Contains configuration such as header text, footer text, sortable/filterable flags, resize constraints, and group column settings.
Structs
- Column
Meta - Metadata for a column that affects its behavior.