Complete aggregation state for the table.
Manages column-level aggregation function assignments and provides configuration for aggregation behavior. Complete aggregation state for the table.
Manages column-level aggregation function assignments and provides configuration for aggregation behavior.
Structs
- Aggregation
State - Complete aggregation state for the table.